@@ -166,6 +166,9 @@ ui_create_main_window()
 
     hildon_program_add_window(app_ui_data->app, app_ui_data->main_view);
 
+    g_signal_connect(G_OBJECT(app_ui_data->main_view), "map-event",
+		    	G_CALLBACK(game_get_screenshot), (gpointer)NULL);
+
     ui_create_indt_menu(app_ui_data);
 
     gtk_widget_show_all(GTK_WIDGET(app_ui_data->main_view));
